# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class SecurityFilterMeta(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "warning": (str,),
        }

    attribute_map = {
        "warning": "warning",
    }

    def __init__(self, *args, **kwargs):
        """
        Optional metadata associated to the response.

        :param warning: A warning message.
        :type warning: str, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SecurityFilterMeta, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
